Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(718)

Unified Diff: src/natives.h

Issue 1094014: Merge the partial_snapshots branch back into bleeding_edge. For... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/natives.h
===================================================================
--- src/natives.h (revision 4215)
+++ src/natives.h (working copy)
@@ -44,13 +44,13 @@
public:
// Number of built-in scripts.
static int GetBuiltinsCount();
- // Number of delayed/lazy loading scripts.
- static int GetDelayCount();
+ // Number of debugger implementation scripts.
+ static int GetDebuggerCount();
- // These are used to access built-in scripts.
- // The delayed script has an index in the interval [0, GetDelayCount()).
- // The non-delayed script has an index in the interval
- // [GetDelayCount(), GetNativesCount()).
+ // These are used to access built-in scripts. The debugger implementation
+ // scripts have an index in the interval [0, GetDebuggerCount()). The
+ // non-debugger scripts have an index in the interval [GetDebuggerCount(),
+ // GetNativesCount()).
static int GetIndex(const char* name);
static Vector<const char> GetScriptSource(int index);
static Vector<const char> GetScriptName(int index);

Powered by Google App Engine
This is Rietveld 408576698